"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AttributesFlavor:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AttributesFlavorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AttributesFlavor.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ATTRIBUTES_FLAVOR_UNSPECIFIED: _AttributesFlavor.ValueType  # 0
    """The flavor is not specified."""
    ACTIVE_DIRECTORY: _AttributesFlavor.ValueType  # 1
    """Active Directory attributes."""

class AttributesFlavor(_AttributesFlavor, metaclass=_AttributesFlavorEnumTypeWrapper):
    """Flavor of attributes to list."""

ATTRIBUTES_FLAVOR_UNSPECIFIED: AttributesFlavor.ValueType  # 0
"""The flavor is not specified."""
ACTIVE_DIRECTORY: AttributesFlavor.ValueType  # 1
"""Active Directory attributes."""
global___AttributesFlavor = AttributesFlavor

@typing.final
class CreateSynchronizationSettingsRequest(google.protobuf.message.Message):
    """Request to create synchronization settings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    REPLACEMENT_DOMAIN_FIELD_NUMBER: builtins.int
    REMOVE_USER_BEHAVIOR_FIELD_NUMBER: builtins.int
    SYNCHRONIZATION_INTERVAL_FIELD_NUMBER: builtins.int
    ALLOW_TO_CAPTURE_USERS_FIELD_NUMBER: builtins.int
    ALLOW_TO_CAPTURE_GROUPS_FIELD_NUMBER: builtins.int
    USER_ATTRIBUTE_MAPPINGS_FIELD_NUMBER: builtins.int
    GROUP_ATTRIBUTE_MAPPINGS_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    replacement_domain: builtins.str
    """Domain replacement configuration."""
    remove_user_behavior: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.RemoveUserBehavior.ValueType
    """Behavior when removing users."""
    allow_to_capture_users: builtins.bool
    """Whether users can be captured during synchronization."""
    allow_to_capture_groups: builtins.bool
    """Whether groups can be captured during synchronization."""
    @property
    def filter(self) -> yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationFilter:
        """Filter configuration for synchronization."""

    @property
    def synchronization_interval(self) -> google.protobuf.duration_pb2.Duration:
        """Interval between synchronization runs."""

    @property
    def user_attribute_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.UserAttributeMapping]:
        """User attribute mappings."""

    @property
    def group_attribute_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.GroupAttributeMapping]:
        """Group attribute mappings."""

    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
        filter: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationFilter | None = ...,
        replacement_domain: builtins.str = ...,
        remove_user_behavior: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.RemoveUserBehavior.ValueType = ...,
        synchronization_interval: google.protobuf.duration_pb2.Duration | None = ...,
        allow_to_capture_users: builtins.bool = ...,
        allow_to_capture_groups: builtins.bool = ...,
        user_attribute_mappings: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.UserAttributeMapping] | None = ...,
        group_attribute_mappings: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.GroupAttributeMapping] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["filter", b"filter", "synchronization_interval", b"synchronization_interval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow_to_capture_groups", b"allow_to_capture_groups", "allow_to_capture_users", b"allow_to_capture_users", "filter", b"filter", "group_attribute_mappings", b"group_attribute_mappings", "remove_user_behavior", b"remove_user_behavior", "replacement_domain", b"replacement_domain", "subject_container_id", b"subject_container_id", "synchronization_interval", b"synchronization_interval", "user_attribute_mappings", b"user_attribute_mappings"]) -> None: ...

global___CreateSynchronizationSettingsRequest = CreateSynchronizationSettingsRequest

@typing.final
class CreateSynchronizationSettingsMetadata(google.protobuf.message.Message):
    """Metadata for the [SynchronizationService.CreateSynchronizationSettings] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subject_container_id", b"subject_container_id"]) -> None: ...

global___CreateSynchronizationSettingsMetadata = CreateSynchronizationSettingsMetadata

@typing.final
class UpdateSynchronizationSettingsRequest(google.protobuf.message.Message):
    """Request to update synchronization settings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    REPLACEMENT_DOMAIN_FIELD_NUMBER: builtins.int
    REMOVE_USER_BEHAVIOR_FIELD_NUMBER: builtins.int
    SYNCHRONIZATION_INTERVAL_FIELD_NUMBER: builtins.int
    ALLOW_TO_CAPTURE_USERS_FIELD_NUMBER: builtins.int
    ALLOW_TO_CAPTURE_GROUPS_FIELD_NUMBER: builtins.int
    USER_ATTRIBUTE_MAPPINGS_FIELD_NUMBER: builtins.int
    GROUP_ATTRIBUTE_MAPPINGS_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    replacement_domain: builtins.str
    """Domain replacement configuration."""
    remove_user_behavior: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.RemoveUserBehavior.ValueType
    """Behavior when removing users."""
    allow_to_capture_users: builtins.bool
    """Whether users can be captured during synchronization."""
    allow_to_capture_groups: builtins.bool
    """Whether groups can be captured during synchronization."""
    @property
    def filter(self) -> yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationFilter:
        """Filter configuration for synchronization."""

    @property
    def synchronization_interval(self) -> google.protobuf.duration_pb2.Duration:
        """Interval between synchronization runs."""

    @property
    def user_attribute_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.UserAttributeMapping]:
        """User attribute mappings."""

    @property
    def group_attribute_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.GroupAttributeMapping]:
        """Group attribute mappings."""

    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields are going to be updated."""

    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
        filter: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationFilter | None = ...,
        replacement_domain: builtins.str = ...,
        remove_user_behavior: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.RemoveUserBehavior.ValueType = ...,
        synchronization_interval: google.protobuf.duration_pb2.Duration | None = ...,
        allow_to_capture_users: builtins.bool = ...,
        allow_to_capture_groups: builtins.bool = ...,
        user_attribute_mappings: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.UserAttributeMapping] | None = ...,
        group_attribute_mappings: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.GroupAttributeMapping] | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["filter", b"filter", "synchronization_interval", b"synchronization_interval", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow_to_capture_groups", b"allow_to_capture_groups", "allow_to_capture_users", b"allow_to_capture_users", "filter", b"filter", "group_attribute_mappings", b"group_attribute_mappings", "remove_user_behavior", b"remove_user_behavior", "replacement_domain", b"replacement_domain", "subject_container_id", b"subject_container_id", "synchronization_interval", b"synchronization_interval", "update_mask", b"update_mask", "user_attribute_mappings", b"user_attribute_mappings"]) -> None: ...

global___UpdateSynchronizationSettingsRequest = UpdateSynchronizationSettingsRequest

@typing.final
class UpdateSynchronizationSettingsMetadata(google.protobuf.message.Message):
    """Metadata for the [SynchronizationService.UpdateSynchronizationSettings] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subject_container_id", b"subject_container_id"]) -> None: ...

global___UpdateSynchronizationSettingsMetadata = UpdateSynchronizationSettingsMetadata

@typing.final
class DeleteSynchronizationSettingsRequest(google.protobuf.message.Message):
    """Request to delete synchronization settings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subject_container_id", b"subject_container_id"]) -> None: ...

global___DeleteSynchronizationSettingsRequest = DeleteSynchronizationSettingsRequest

@typing.final
class DeleteSynchronizationSettingsMetadata(google.protobuf.message.Message):
    """Metadata for the [SynchronizationService.DeleteSynchronizationSettings] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subject_container_id", b"subject_container_id"]) -> None: ...

global___DeleteSynchronizationSettingsMetadata = DeleteSynchronizationSettingsMetadata

@typing.final
class GetSynchronizationSettingsRequest(google.protobuf.message.Message):
    """Request to get synchronization settings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subject_container_id", b"subject_container_id"]) -> None: ...

global___GetSynchronizationSettingsRequest = GetSynchronizationSettingsRequest

@typing.final
class ListSupportedAttributesRequest(google.protobuf.message.Message):
    """Request to list supported attributes."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLAVOR_FIELD_NUMBER: builtins.int
    flavor: global___AttributesFlavor.ValueType
    """Flavor of attributes to list."""
    def __init__(
        self,
        *,
        flavor: global___AttributesFlavor.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["flavor", b"flavor"]) -> None: ...

global___ListSupportedAttributesRequest = ListSupportedAttributesRequest

@typing.final
class ListSupportedAttributesResponse(google.protobuf.message.Message):
    """Response message for [SynchronizationService.ListSupportedAttributes]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_SUPPORTED_ATTRIBUTES_FIELD_NUMBER: builtins.int
    GROUP_SUPPORTED_ATTRIBUTES_FIELD_NUMBER: builtins.int
    @property
    def user_supported_attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserSupportedAttribute]:
        """List of supported user attributes."""

    @property
    def group_supported_attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GroupSupportedAttribute]:
        """List of supported group attributes."""

    def __init__(
        self,
        *,
        user_supported_attributes: collections.abc.Iterable[global___UserSupportedAttribute] | None = ...,
        group_supported_attributes: collections.abc.Iterable[global___GroupSupportedAttribute] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_supported_attributes", b"group_supported_attributes", "user_supported_attributes", b"user_supported_attributes"]) -> None: ...

global___ListSupportedAttributesResponse = ListSupportedAttributesResponse

@typing.final
class UserSupportedAttribute(google.protobuf.message.Message):
    """Supported user attribute configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_ATTRIBUTE_FIELD_NUMBER: builtins.int
    SOURCE_ATTRIBUTES_FIELD_NUMBER: builtins.int
    target_attribute: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.UserTargetAttribute.ValueType
    """Target attribute to map to."""
    @property
    def source_attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SourceAttributes]:
        """List of source attribute configurations."""

    def __init__(
        self,
        *,
        target_attribute: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.UserTargetAttribute.ValueType = ...,
        source_attributes: collections.abc.Iterable[global___SourceAttributes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["source_attributes", b"source_attributes", "target_attribute", b"target_attribute"]) -> None: ...

global___UserSupportedAttribute = UserSupportedAttribute

@typing.final
class GroupSupportedAttribute(google.protobuf.message.Message):
    """Supported group attribute configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_ATTRIBUTE_FIELD_NUMBER: builtins.int
    SOURCE_ATTRIBUTES_FIELD_NUMBER: builtins.int
    target_attribute: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.GroupTargetAttribute.ValueType
    """Target attribute to map to."""
    @property
    def source_attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SourceAttributes]:
        """List of source attribute configurations."""

    def __init__(
        self,
        *,
        target_attribute: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.GroupTargetAttribute.ValueType = ...,
        source_attributes: collections.abc.Iterable[global___SourceAttributes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["source_attributes", b"source_attributes", "target_attribute", b"target_attribute"]) -> None: ...

global___GroupSupportedAttribute = GroupSupportedAttribute

@typing.final
class SourceAttributes(google.protobuf.message.Message):
    """Source attribute configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    type: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.MappingType.ValueType
    """Type of mapping."""
    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of source attribute names. Empty for EMPTY type."""

    def __init__(
        self,
        *,
        type: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.MappingType.ValueType = ...,
        attributes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["attributes", b"attributes", "type", b"type"]) -> None: ...

global___SourceAttributes = SourceAttributes

@typing.final
class SetReplicationTokenRequest(google.protobuf.message.Message):
    """Request to set replication token."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    REPLICATION_TOKEN_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    replication_token: builtins.str
    """Replication token value."""
    session_type: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SessionType.ValueType
    """Type of synchronization session."""
    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
        replication_token: builtins.str = ...,
        session_type: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SessionType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["replication_token", b"replication_token", "session_type", b"session_type", "subject_container_id", b"subject_container_id"]) -> None: ...

global___SetReplicationTokenRequest = SetReplicationTokenRequest

@typing.final
class SetReplicationTokenMetadata(google.protobuf.message.Message):
    """Metadata for the [SynchronizationService.SetReplicationToken] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subject_container_id", b"subject_container_id"]) -> None: ...

global___SetReplicationTokenMetadata = SetReplicationTokenMetadata

@typing.final
class ResetReplicationTokenRequest(google.protobuf.message.Message):
    """Request to reset replication token."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subject_container_id", b"subject_container_id"]) -> None: ...

global___ResetReplicationTokenRequest = ResetReplicationTokenRequest

@typing.final
class ResetReplicationTokenMetadata(google.protobuf.message.Message):
    """Metadata for the [SynchronizationService.ResetReplicationToken] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subject_container_id", b"subject_container_id"]) -> None: ...

global___ResetReplicationTokenMetadata = ResetReplicationTokenMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/synchronization_settings.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/synchronization_settings.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFyandex/cloud/organizationmanager/v1/idp/synchronization_settings.proto\x12\'yandex.cloud.organizationmanager.v1.idp\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xee\x04\n\x17SynchronizationSettings\x12\x1c\n\x14subject_container_id\x18\x01 \x01(\t\x12N\n\x06\x66ilter\x18\x02 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.SynchronizationFilter\x12Y\n\x14remove_user_behavior\x18\x03 \x01(\x0e\x32;.yandex.cloud.organizationmanager.v1.idp.RemoveUserBehavior\x12;\n\x18synchronization_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1e\n\x16\x61llow_to_capture_users\x18\x05 \x01(\x08\x12\x1f\n\x17\x61llow_to_capture_groups\x18\x06 \x01(\x08\x12^\n\x17user_attribute_mappings\x18\x07 \x03(\x0b\x32=.yandex.cloud.organizationmanager.v1.idp.UserAttributeMapping\x12`\n\x18group_attribute_mappings\x18\x08 \x03(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.GroupAttributeMapping\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12replacement_domain\x18\n \x01(\t\"\x88\x01\n\x15SynchronizationFilter\x12\x1d\n\x06\x64omain\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-253\x12!\n\x06groups\x18\x02 \x03(\tB\x11\x82\xc8\x31\x04<=10\x8a\xc8\x31\x05\x31-253\x12-\n\x12organization_units\x18\x03 \x03(\tB\x11\x82\xc8\x31\x04<=10\x8a\xc8\x31\x05\x31-253\"\xcf\x01\n\x14UserAttributeMapping\x12\x19\n\x06source\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x30-253\x12R\n\x06target\x18\x02 \x01(\x0e\x32<.yandex.cloud.organizationmanager.v1.idp.UserTargetAttributeB\x04\xe8\xc7\x31\x01\x12H\n\x04type\x18\x03 \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.MappingTypeB\x04\xe8\xc7\x31\x01\"\xd1\x01\n\x15GroupAttributeMapping\x12\x19\n\x06source\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x30-253\x12S\n\x06target\x18\x02 \x01(\x0e\x32=.yandex.cloud.organizationmanager.v1.idp.GroupTargetAttributeB\x04\xe8\xc7\x31\x01\x12H\n\x04type\x18\x03 \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.MappingTypeB\x04\xe8\xc7\x31\x01*B\n\x0bMappingType\x12\x1c\n\x18MAPPING_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x44IRECT\x10\x01\x12\t\n\x05\x45MPTY\x10\x02*\xd9\x01\n\x13UserTargetAttribute\x12%\n!USER_TARGET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\r\n\tFULL_NAME\x10\x01\x12\x0e\n\nGIVEN_NAME\x10\x02\x12\x0f\n\x0b\x46\x41MILY_NAME\x10\x03\x12\t\n\x05\x45MAIL\x10\x04\x12\x10\n\x0cPHONE_NUMBER\x10\x05\x12\x0c\n\x08USERNAME\x10\x06\x12\x10\n\x0c\x43OMPANY_NAME\x10\x07\x12\r\n\tJOB_TITLE\x10\x08\x12\x0e\n\nDEPARTMENT\x10\t\x12\x0f\n\x0b\x45MPLOYEE_ID\x10\n*Y\n\x14GroupTargetAttribute\x12&\n\"GROUP_TARGET_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x02*Q\n\x12RemoveUserBehavior\x12$\n REMOVE_USER_BEHAVIOR_UNSPECIFIED\x10\x00\x12\n\n\x06REMOVE\x10\x01\x12\t\n\x05\x42LOCK\x10\x02*c\n\x0bSessionType\x12\x1c\n\x18SESSION_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x41\x44_SYNC\x10\x01\x12\x14\n\x10\x41\x44_PASSWORD_HASH\x10\x02\x12\x13\n\x0f\x41\x44_USER_CONTROL\x10\x03\x42~\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idp'
  _globals['_SYNCHRONIZATIONFILTER'].fields_by_name['domain']._loaded_options = None
  _globals['_SYNCHRONIZATIONFILTER'].fields_by_name['domain']._serialized_options = b'\350\3071\001\212\3101\0051-253'
  _globals['_SYNCHRONIZATIONFILTER'].fields_by_name['groups']._loaded_options = None
  _globals['_SYNCHRONIZATIONFILTER'].fields_by_name['groups']._serialized_options = b'\202\3101\004<=10\212\3101\0051-253'
  _globals['_SYNCHRONIZATIONFILTER'].fields_by_name['organization_units']._loaded_options = None
  _globals['_SYNCHRONIZATIONFILTER'].fields_by_name['organization_units']._serialized_options = b'\202\3101\004<=10\212\3101\0051-253'
  _globals['_USERATTRIBUTEMAPPING'].fields_by_name['source']._loaded_options = None
  _globals['_USERATTRIBUTEMAPPING'].fields_by_name['source']._serialized_options = b'\212\3101\0050-253'
  _globals['_USERATTRIBUTEMAPPING'].fields_by_name['target']._loaded_options = None
  _globals['_USERATTRIBUTEMAPPING'].fields_by_name['target']._serialized_options = b'\350\3071\001'
  _globals['_USERATTRIBUTEMAPPING'].fields_by_name['type']._loaded_options = None
  _globals['_USERATTRIBUTEMAPPING'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_GROUPATTRIBUTEMAPPING'].fields_by_name['source']._loaded_options = None
  _globals['_GROUPATTRIBUTEMAPPING'].fields_by_name['source']._serialized_options = b'\212\3101\0050-253'
  _globals['_GROUPATTRIBUTEMAPPING'].fields_by_name['target']._loaded_options = None
  _globals['_GROUPATTRIBUTEMAPPING'].fields_by_name['target']._serialized_options = b'\350\3071\001'
  _globals['_GROUPATTRIBUTEMAPPING'].fields_by_name['type']._loaded_options = None
  _globals['_GROUPATTRIBUTEMAPPING'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_MAPPINGTYPE']._serialized_start=1397
  _globals['_MAPPINGTYPE']._serialized_end=1463
  _globals['_USERTARGETATTRIBUTE']._serialized_start=1466
  _globals['_USERTARGETATTRIBUTE']._serialized_end=1683
  _globals['_GROUPTARGETATTRIBUTE']._serialized_start=1685
  _globals['_GROUPTARGETATTRIBUTE']._serialized_end=1774
  _globals['_REMOVEUSERBEHAVIOR']._serialized_start=1776
  _globals['_REMOVEUSERBEHAVIOR']._serialized_end=1857
  _globals['_SESSIONTYPE']._serialized_start=1859
  _globals['_SESSIONTYPE']._serialized_end=1958
  _globals['_SYNCHRONIZATIONSETTINGS']._serialized_start=212
  _globals['_SYNCHRONIZATIONSETTINGS']._serialized_end=834
  _globals['_SYNCHRONIZATIONFILTER']._serialized_start=837
  _globals['_SYNCHRONIZATIONFILTER']._serialized_end=973
  _globals['_USERATTRIBUTEMAPPING']._serialized_start=976
  _globals['_USERATTRIBUTEMAPPING']._serialized_end=1183
  _globals['_GROUPATTRIBUTEMAPPING']._serialized_start=1186
  _globals['_GROUPATTRIBUTEMAPPING']._serialized_end=1395
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DeleteLifecycleRuleKind:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeleteLifecycleRuleKindEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeleteLifecycleRuleKind.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DELETE_LIFECYCLE_RULE_KIND_UNSPECIFIED: _DeleteLifecycleRuleKind.ValueType  # 0
    HARD_DELETE: _DeleteLifecycleRuleKind.ValueType  # 1
    """Hard delete - artifacts are permanently removed."""
    SOFT_DELETE: _DeleteLifecycleRuleKind.ValueType  # 2
    """Soft delete - artifacts are marked for deletion but can be recovered."""

class DeleteLifecycleRuleKind(_DeleteLifecycleRuleKind, metaclass=_DeleteLifecycleRuleKindEnumTypeWrapper):
    """Type of deletion for lifecycle rules."""

DELETE_LIFECYCLE_RULE_KIND_UNSPECIFIED: DeleteLifecycleRuleKind.ValueType  # 0
HARD_DELETE: DeleteLifecycleRuleKind.ValueType  # 1
"""Hard delete - artifacts are permanently removed."""
SOFT_DELETE: DeleteLifecycleRuleKind.ValueType  # 2
"""Soft delete - artifacts are marked for deletion but can be recovered."""
global___DeleteLifecycleRuleKind = DeleteLifecycleRuleKind

class _LifecyclePolicyState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LifecyclePolicyStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LifecyclePolicyState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LIFECYCLE_POLICY_STATE_UNSPECIFIED: _LifecyclePolicyState.ValueType  # 0
    DISABLED: _LifecyclePolicyState.ValueType  # 1
    """Policy is disabled and won't be executed."""
    ENABLED: _LifecyclePolicyState.ValueType  # 2
    """Policy is enabled and will be executed according to schedule."""

class LifecyclePolicyState(_LifecyclePolicyState, metaclass=_LifecyclePolicyStateEnumTypeWrapper):
    """State of the lifecycle policy."""

LIFECYCLE_POLICY_STATE_UNSPECIFIED: LifecyclePolicyState.ValueType  # 0
DISABLED: LifecyclePolicyState.ValueType  # 1
"""Policy is disabled and won't be executed."""
ENABLED: LifecyclePolicyState.ValueType  # 2
"""Policy is enabled and will be executed according to schedule."""
global___LifecyclePolicyState = LifecyclePolicyState

@typing.final
class LifecyclePolicy(google.protobuf.message.Message):
    """A LifecyclePolicy resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    REGISTRY_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    MODIFIED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    MODIFIED_BY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the lifecycle policy."""
    name: builtins.str
    """Name of the lifecycle policy."""
    description: builtins.str
    """Description of the lifecycle policy. 0-1024 characters long."""
    state: global___LifecyclePolicyState.ValueType
    """Current state of the lifecycle policy."""
    registry_id: builtins.str
    """ID of the registry that the lifecycle policy belongs to."""
    created_by: builtins.str
    """Output only. ID of the user who created the lifecycle policy."""
    modified_by: builtins.str
    """Output only. ID of the user who last modified the lifecycle policy."""
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LifecycleRule]:
        """List of lifecycle rules."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Output only. Creation timestamp."""

    @property
    def modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Output only. Modification timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        rules: collections.abc.Iterable[global___LifecycleRule] | None = ...,
        state: global___LifecyclePolicyState.ValueType = ...,
        registry_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        modified_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "modified_at", b"modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "created_by", b"created_by", "description", b"description", "id", b"id", "modified_at", b"modified_at", "modified_by", b"modified_by", "name", b"name", "registry_id", b"registry_id", "rules", b"rules", "state", b"state"]) -> None: ...

global___LifecyclePolicy = LifecyclePolicy

@typing.final
class LifecycleRule(google.protobuf.message.Message):
    """A rule that defines lifecycle policy behavior."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_PREFIX_FIELD_NUMBER: builtins.int
    KEEP_BY_AGE_FIELD_NUMBER: builtins.int
    KEEP_BY_VERSION_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    DOCKER_FILTERS_FIELD_NUMBER: builtins.int
    MAVEN_FILTERS_FIELD_NUMBER: builtins.int
    VERSION_REGEXP_FIELD_NUMBER: builtins.int
    path_prefix: builtins.str
    """Path prefix to which the rule applies."""
    version_regexp: builtins.str
    """Regular expression pattern to match package version or docker tag."""
    @property
    def keep_by_age(self) -> global___KeepByAgeLifecycleRule:
        """Rule that keeps artifacts by age."""

    @property
    def keep_by_version(self) -> global___KeepByVersionLifecycleRule:
        """Rule that keeps artifacts by version count."""

    @property
    def delete(self) -> global___DeleteLifecycleRule:
        """Rule that deletes artifacts."""

    @property
    def docker_filters(self) -> global___DockerFilters:
        """Docker-specific filters."""

    @property
    def maven_filters(self) -> global___MavenFilters:
        """Maven-specific filters."""

    def __init__(
        self,
        *,
        path_prefix: builtins.str = ...,
        keep_by_age: global___KeepByAgeLifecycleRule | None = ...,
        keep_by_version: global___KeepByVersionLifecycleRule | None = ...,
        delete: global___DeleteLifecycleRule | None = ...,
        docker_filters: global___DockerFilters | None = ...,
        maven_filters: global___MavenFilters | None = ...,
        version_regexp: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["delete", b"delete", "docker_filters", b"docker_filters", "filter", b"filter", "keep_by_age", b"keep_by_age", "keep_by_version", b"keep_by_version", "kind", b"kind", "maven_filters", b"maven_filters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["delete", b"delete", "docker_filters", b"docker_filters", "filter", b"filter", "keep_by_age", b"keep_by_age", "keep_by_version", b"keep_by_version", "kind", b"kind", "maven_filters", b"maven_filters", "path_prefix", b"path_prefix", "version_regexp", b"version_regexp"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["filter", b"filter"]) -> typing.Literal["docker_filters", "maven_filters"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["kind", b"kind"]) -> typing.Literal["keep_by_age", "keep_by_version", "delete"] | None: ...

global___LifecycleRule = LifecycleRule

@typing.final
class DockerFilters(google.protobuf.message.Message):
    """Docker-specific filters for lifecycle rules."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _TagStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TagStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DockerFilters._TagStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TAG_STATUS_UNSPECIFIED: DockerFilters._TagStatus.ValueType  # 0
        TAG_STATUS_ANY: DockerFilters._TagStatus.ValueType  # 1
        """Any tag status."""
        TAGGED: DockerFilters._TagStatus.ValueType  # 2
        """Only tagged images."""
        UNTAGGED: DockerFilters._TagStatus.ValueType  # 3
        """Only untagged images."""

    class TagStatus(_TagStatus, metaclass=_TagStatusEnumTypeWrapper): ...
    TAG_STATUS_UNSPECIFIED: DockerFilters.TagStatus.ValueType  # 0
    TAG_STATUS_ANY: DockerFilters.TagStatus.ValueType  # 1
    """Any tag status."""
    TAGGED: DockerFilters.TagStatus.ValueType  # 2
    """Only tagged images."""
    UNTAGGED: DockerFilters.TagStatus.ValueType  # 3
    """Only untagged images."""

    TAG_STATUS_FIELD_NUMBER: builtins.int
    tag_status: global___DockerFilters.TagStatus.ValueType
    """Filter by tag status."""
    def __init__(
        self,
        *,
        tag_status: global___DockerFilters.TagStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tag_status", b"tag_status"]) -> None: ...

global___DockerFilters = DockerFilters

@typing.final
class MavenFilters(google.protobuf.message.Message):
    """Maven-specific filters for lifecycle rules."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _VersionType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _VersionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MavenFilters._VersionType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VERSION_TYPE_UNSPECIFIED: MavenFilters._VersionType.ValueType  # 0
        VERSION_TYPE_ANY: MavenFilters._VersionType.ValueType  # 1
        """Any version type."""
        RELEASE: MavenFilters._VersionType.ValueType  # 2
        """Only release versions."""
        SNAPSHOT: MavenFilters._VersionType.ValueType  # 3
        """Only snapshot versions."""

    class VersionType(_VersionType, metaclass=_VersionTypeEnumTypeWrapper): ...
    VERSION_TYPE_UNSPECIFIED: MavenFilters.VersionType.ValueType  # 0
    VERSION_TYPE_ANY: MavenFilters.VersionType.ValueType  # 1
    """Any version type."""
    RELEASE: MavenFilters.VersionType.ValueType  # 2
    """Only release versions."""
    SNAPSHOT: MavenFilters.VersionType.ValueType  # 3
    """Only snapshot versions."""

    VERSION_TYPE_FIELD_NUMBER: builtins.int
    version_type: global___MavenFilters.VersionType.ValueType
    """Filter by version type."""
    def __init__(
        self,
        *,
        version_type: global___MavenFilters.VersionType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["version_type", b"version_type"]) -> None: ...

global___MavenFilters = MavenFilters

@typing.final
class KeepByVersionLifecycleRule(google.protobuf.message.Message):
    """Rule that keeps a specified number of recent versions."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEEP_VERSIONS_COUNT_FIELD_NUMBER: builtins.int
    keep_versions_count: builtins.int
    """Number of versions to keep."""
    def __init__(
        self,
        *,
        keep_versions_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["keep_versions_count", b"keep_versions_count"]) -> None: ...

global___KeepByVersionLifecycleRule = KeepByVersionLifecycleRule

@typing.final
class KeepByAgeLifecycleRule(google.protobuf.message.Message):
    """Rule that keeps artifacts younger than specified age."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    YOUNGER_THAN_DAYS_FIELD_NUMBER: builtins.int
    younger_than_days: builtins.int
    """Keep artifacts younger than this number of days."""
    def __init__(
        self,
        *,
        younger_than_days: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["younger_than_days", b"younger_than_days"]) -> None: ...

global___KeepByAgeLifecycleRule = KeepByAgeLifecycleRule

@typing.final
class DeleteLifecycleRule(google.protobuf.message.Message):
    """Rule that deletes artifacts based on specified conditions."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    COOLDOWN_PERIOD_DAYS_FIELD_NUMBER: builtins.int
    OLDER_THAN_DAYS_FIELD_NUMBER: builtins.int
    VERSION_CONDITION_FIELD_NUMBER: builtins.int
    ALWAYS_FIELD_NUMBER: builtins.int
    type: global___DeleteLifecycleRuleKind.ValueType
    """Type of deletion."""
    cooldown_period_days: builtins.int
    """Cooldown period in days before deletion."""
    older_than_days: builtins.int
    """Delete artifacts older than specified days."""
    always: builtins.bool
    """Always delete (use with caution)."""
    @property
    def version_condition(self) -> global___DeleteByVersionCondition:
        """Delete artifacts by version count condition."""

    def __init__(
        self,
        *,
        type: global___DeleteLifecycleRuleKind.ValueType = ...,
        cooldown_period_days: builtins.int = ...,
        older_than_days: builtins.int = ...,
        version_condition: global___DeleteByVersionCondition | None = ...,
        always: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["always", b"always", "condition", b"condition", "older_than_days", b"older_than_days", "version_condition", b"version_condition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["always", b"always", "condition", b"condition", "cooldown_period_days", b"cooldown_period_days", "older_than_days", b"older_than_days", "type", b"type", "version_condition", b"version_condition"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["condition", b"condition"]) -> typing.Literal["older_than_days", "version_condition", "always"] | None: ...

global___DeleteLifecycleRule = DeleteLifecycleRule

@typing.final
class DeleteByVersionCondition(google.protobuf.message.Message):
    """Condition for deletion based on version count."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSIONS_COUNT_GREATER_THAN_FIELD_NUMBER: builtins.int
    versions_count_greater_than: builtins.int
    """Delete when version count exceeds this number."""
    def __init__(
        self,
        *,
        versions_count_greater_than: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["versions_count_greater_than", b"versions_count_greater_than"]) -> None: ...

global___DeleteByVersionCondition = DeleteByVersionCondition



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SortOrder:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SortOrderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SortOrder.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SORT_ORDER_UNSPECIFIED: _SortOrder.ValueType  # 0
    """Not specified."""
    ASC: _SortOrder.ValueType  # 1
    """Asceding sort order."""
    DESC: _SortOrder.ValueType  # 2
    """Desceding sort order."""

class SortOrder(_SortOrder, metaclass=_SortOrderEnumTypeWrapper): ...

SORT_ORDER_UNSPECIFIED: SortOrder.ValueType  # 0
"""Not specified."""
ASC: SortOrder.ValueType  # 1
"""Asceding sort order."""
DESC: SortOrder.ValueType  # 2
"""Desceding sort order."""
global___SortOrder = SortOrder



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AssignmentAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AssignmentActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AssignmentAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ASSIGNMENT_ACTION_UNSPECIFIED: _AssignmentAction.ValueType  # 0
    """Action unspecified"""
    ADD: _AssignmentAction.ValueType  # 1
    """Add action"""
    REMOVE: _AssignmentAction.ValueType  # 2
    """Remove action"""

class AssignmentAction(_AssignmentAction, metaclass=_AssignmentActionEnumTypeWrapper):
    """The action within assignment delta that is being performed on an assignment"""

ASSIGNMENT_ACTION_UNSPECIFIED: AssignmentAction.ValueType  # 0
"""Action unspecified"""
ADD: AssignmentAction.ValueType  # 1
"""Add action"""
REMOVE: AssignmentAction.ValueType  # 2
"""Remove action"""
global___AssignmentAction = AssignmentAction

@typing.final
class GetApplicationRequest(google.protobuf.message.Message):
    """Request to get a OAuth application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application to return.
    To get the OAuth application ID, make a [ApplicationService.List] request.
    """
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___GetApplicationRequest = GetApplicationRequest

@typing.final
class ListApplicationsRequest(google.protobuf.message.Message):
    """Request to list OAuth applications."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to list OAuth applications in."""
    page_size: builtins.int
    """The maximum number of results per page to return.
    If the number of available results is larger than [page_size],
    the service returns a [ListApplicationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListApplicationsResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response."""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListApplicationsRequest = ListApplicationsRequest

@typing.final
class ListApplicationsResponse(google.protobuf.message.Message):
    """Response message for [ApplicationService.List]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.
    If the number of results is larger than [ListApplicationsRequest.page_size],
    use the [next_page_token] as the value for the [ListApplicationsRequest.page_token]
    query parameter in the next list request.
    """
    @property
    def applications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.Application]:
        """List of OAuth applications."""

    def __init__(
        self,
        *,
        applications: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.Application] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["applications", b"applications", "next_page_token", b"next_page_token"]) -> None: ...

global___ListApplicationsResponse = ListApplicationsResponse

@typing.final
class CreateApplicationRequest(google.protobuf.message.Message):
    """Request to create a OAuth application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    GROUP_CLAIMS_SETTINGS_FIELD_NUMBER: builtins.int
    CLIENT_GRANT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the OAuth application.
    The name must be unique within the organization.
    """
    organization_id: builtins.str
    """ID of the organization to create a OAuth application in."""
    description: builtins.str
    """Description of the OAuth application."""
    @property
    def group_claims_settings(self) -> yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.GroupClaimsSettings:
        """Settings of the group claims"""

    @property
    def client_grant(self) -> yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.ClientGrant:
        """Connection to the OAuth client with specified scopes"""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as key:value pairs."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        organization_id: builtins.str = ...,
        description: builtins.str = ...,
        group_claims_settings: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.GroupClaimsSettings | None = ...,
        client_grant: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.ClientGrant | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["client_grant", b"client_grant", "group_claims_settings", b"group_claims_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["client_grant", b"client_grant", "description", b"description", "group_claims_settings", b"group_claims_settings", "labels", b"labels", "name", b"name", "organization_id", b"organization_id"]) -> None: ...

global___CreateApplicationRequest = CreateApplicationRequest

@typing.final
class CreateApplicationMetadata(google.protobuf.message.Message):
    """Metadata for the [ApplicationService.Create] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application that is being created."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___CreateApplicationMetadata = CreateApplicationMetadata

@typing.final
class UpdateApplicationRequest(google.protobuf.message.Message):
    """Request to update a OAuth application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    GROUP_CLAIMS_SETTINGS_FIELD_NUMBER: builtins.int
    CLIENT_GRANT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application to update.
    To get the OAuth application ID, make a [ApplicationService.List] request.
    """
    name: builtins.str
    """Name of the OAuth application.
    The name must be unique within the organization.
    """
    description: builtins.str
    """Description of the OAuth application."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the OAuth application are going to be updated."""

    @property
    def group_claims_settings(self) -> yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.GroupClaimsSettings:
        """Settings of the group claims"""

    @property
    def client_grant(self) -> yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.ClientGrant:
        """Connection to the OAuth client with specified scopes"""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as key:value pairs."""

    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        group_claims_settings: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.GroupClaimsSettings | None = ...,
        client_grant: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.ClientGrant | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["client_grant", b"client_grant", "group_claims_settings", b"group_claims_settings", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id", "client_grant", b"client_grant", "description", b"description", "group_claims_settings", b"group_claims_settings", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateApplicationRequest = UpdateApplicationRequest

@typing.final
class UpdateApplicationMetadata(google.protobuf.message.Message):
    """Metadata for the [ApplicationService.Update] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application that is being updated."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___UpdateApplicationMetadata = UpdateApplicationMetadata

@typing.final
class SuspendApplicationRequest(google.protobuf.message.Message):
    """Request to suspend a OAuth application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application to suspend.
    To get the OAuth application ID, make a [ApplicationService.List] request.
    """
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___SuspendApplicationRequest = SuspendApplicationRequest

@typing.final
class SuspendApplicationMetadata(google.protobuf.message.Message):
    """Metadata for the [ApplicationService.Suspend] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application that is being suspended."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___SuspendApplicationMetadata = SuspendApplicationMetadata

@typing.final
class ReactivateApplicationRequest(google.protobuf.message.Message):
    """Request to reactivate a OAuth application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application to reactivate.
    To get the OAuth application ID, make a [ApplicationService.List] request.
    """
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___ReactivateApplicationRequest = ReactivateApplicationRequest

@typing.final
class ReactivateApplicationMetadata(google.protobuf.message.Message):
    """Metadata for the [ApplicationService.Reactivate] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application that is being reactivated."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___ReactivateApplicationMetadata = ReactivateApplicationMetadata

@typing.final
class DeleteApplicationRequest(google.protobuf.message.Message):
    """Request to delete a OAuth application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application to delete.
    To get the OAuth application ID, make a [ApplicationService.List] request.
    """
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___DeleteApplicationRequest = DeleteApplicationRequest

@typing.final
class DeleteApplicationMetadata(google.protobuf.message.Message):
    """Metadata for the [ApplicationService.Delete] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application that is being deleted."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___DeleteApplicationMetadata = DeleteApplicationMetadata

@typing.final
class ListApplicationOperationsRequest(google.protobuf.message.Message):
    """Request to list operations for a OAuth application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return."""
    page_token: builtins.str
    """Page token for pagination."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListApplicationOperationsRequest = ListApplicationOperationsRequest

@typing.final
class ListApplicationOperationsResponse(google.protobuf.message.Message):
    """Response message for [ApplicationService.ListOperations]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list."""
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListApplicationOperationsResponse = ListApplicationOperationsResponse

@typing.final
class Assignment(google.protobuf.message.Message):
    """An assignment for the OAuth application"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_ID_FIELD_NUMBER: builtins.int
    subject_id: builtins.str
    """ID of the subject to be assigned to the OAuth application.
    Supported subject categories: UserAccount, ServiceAccount, Group, MetaGroup, PublicGroup.
    In case subject ID is ID of the group, 
    then such group becomes visible to the users of OAuth application in case [GroupDistributionType] has value ASSIGNED_GROUPS.
    """
    def __init__(
        self,
        *,
        subject_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subject_id", b"subject_id"]) -> None: ...

global___Assignment = Assignment

@typing.final
class AssignmentDelta(google.protobuf.message.Message):
    """A delta of the"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    ASSIGNMENT_FIELD_NUMBER: builtins.int
    action: global___AssignmentAction.ValueType
    """The action that is being performed on an assignment."""
    @property
    def assignment(self) -> global___Assignment:
        """An assignment for the OAuth application."""

    def __init__(
        self,
        *,
        action: global___AssignmentAction.ValueType = ...,
        assignment: global___Assignment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["assignment", b"assignment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "assignment", b"assignment"]) -> None: ...

global___AssignmentDelta = AssignmentDelta

@typing.final
class UpdateAssignmentsResponse(google.protobuf.message.Message):
    """Response message of the operation for the [ApplicationService.UpdateAssignments]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSIGNMENT_DELTAS_FIELD_NUMBER: builtins.int
    @property
    def assignment_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssignmentDelta]:
        """List of applied assignment deltas on the OAuth application"""

    def __init__(
        self,
        *,
        assignment_deltas: collections.abc.Iterable[global___AssignmentDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["assignment_deltas", b"assignment_deltas"]) -> None: ...

global___UpdateAssignmentsResponse = UpdateAssignmentsResponse

@typing.final
class ListAssignmentsRequest(google.protobuf.message.Message):
    """Request to list assignments for a OAuth application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application to update.
    To get the OAuth application ID, make a [ApplicationService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.
    If the number of available results is larger than [page_size],
    the service returns a [ListAssignmentsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListAssignmentsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListAssignmentsRequest = ListAssignmentsRequest

@typing.final
class ListAssignmentsResponse(google.protobuf.message.Message):
    """Response message for [ApplicationService.ListAssignments]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSIGNMENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.
    If the number of results is larger than [ListAssignmentsRequest.page_size],
    use the [next_page_token] as the value for the [ListAssignmentsRequest.page_token]
    query parameter in the next list request.
    """
    @property
    def assignments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Assignment]:
        """List of assignments."""

    def __init__(
        self,
        *,
        assignments: collections.abc.Iterable[global___Assignment] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["assignments", b"assignments", "next_page_token", b"next_page_token"]) -> None: ...

global___ListAssignmentsResponse = ListAssignmentsResponse

@typing.final
class UpdateAssignmentsRequest(google.protobuf.message.Message):
    """Request to update assignments for specified OAuth application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    ASSIGNMENT_DELTAS_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application to update.
    To get the OAuth application ID, make a [ApplicationService.List] request.
    """
    @property
    def assignment_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssignmentDelta]:
        """List of assignment deltas to be applied on the OAuth application. Duplicates or invalid assignments are ignored."""

    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        assignment_deltas: collections.abc.Iterable[global___AssignmentDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id", "assignment_deltas", b"assignment_deltas"]) -> None: ...

global___UpdateAssignmentsRequest = UpdateAssignmentsRequest

@typing.final
class UpdateAssignmentsMetadata(google.protobuf.message.Message):
    """Metadata for the [ApplicationService.UpdateAssignments] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the OAuth application that is being updated."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id"]) -> None: ...

global___UpdateAssignmentsMetadata = UpdateAssignmentsMetadata



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp import synchronization_session_service_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/organizationmanager/v1/idp/synchronization_session_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SynchronizationSessionServiceStub(object):
    """A set of methods for managing synchronization sessions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.OpenSession = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService/OpenSession',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.OpenSessionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.CloseSession = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService/CloseSession',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.CloseSessionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ReportSessionProgress = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService/ReportSessionProgress',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.ReportSessionProgressRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Heartbeat = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService/Heartbeat',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.HeartbeatRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.GetSession = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService/GetSession',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.GetSessionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.GetSessionResponse.FromString,
                _registered_method=True)
        self.ListSessions = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService/ListSessions',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.ListSessionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.ListSessionsResponse.FromString,
                _registered_method=True)


class SynchronizationSessionServiceServicer(object):
    """A set of methods for managing synchronization sessions.
    """

    def OpenSession(self, request, context):
        """Opens a new synchronization session.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloseSession(self, request, context):
        """Closes a synchronization session.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportSessionProgress(self, request, context):
        """Reports progress for a synchronization session.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Heartbeat(self, request, context):
        """Sends a heartbeat for a synchronization session.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSession(self, request, context):
        """Returns the specified synchronization session.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSessions(self, request, context):
        """Lists synchronization sessions for a subject container.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SynchronizationSessionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'OpenSession': grpc.unary_unary_rpc_method_handler(
                    servicer.OpenSession,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.OpenSessionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'CloseSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CloseSession,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.CloseSessionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ReportSessionProgress': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportSessionProgress,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.ReportSessionProgressRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Heartbeat': grpc.unary_unary_rpc_method_handler(
                    servicer.Heartbeat,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.HeartbeatRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetSession': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSession,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.GetSessionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.GetSessionResponse.SerializeToString,
            ),
            'ListSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSessions,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.ListSessionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.ListSessionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SynchronizationSessionService(object):
    """A set of methods for managing synchronization sessions.
    """

    @staticmethod
    def OpenSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService/OpenSession',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.OpenSessionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CloseSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService/CloseSession',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.CloseSessionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReportSessionProgress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService/ReportSessionProgress',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.ReportSessionProgressRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Heartbeat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService/Heartbeat',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.HeartbeatRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService/GetSession',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.GetSessionRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.GetSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionService/ListSessions',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.ListSessionsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__session__service__pb2.ListSessionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.searchapi.v2 import wordstat_service_pb2 as yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/searchapi/v2/wordstat_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class WordstatServiceStub(object):
    """A set of methods for viewing statistics on search queries to Yandex.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetTop = channel.unary_unary(
                '/yandex.cloud.searchapi.v2.WordstatService/GetTop',
                request_serializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetTopRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetTopResponse.FromString,
                _registered_method=True)
        self.GetDynamics = channel.unary_unary(
                '/yandex.cloud.searchapi.v2.WordstatService/GetDynamics',
                request_serializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetDynamicsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetDynamicsResponse.FromString,
                _registered_method=True)
        self.GetRegionsDistribution = channel.unary_unary(
                '/yandex.cloud.searchapi.v2.WordstatService/GetRegionsDistribution',
                request_serializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetRegionsDistributionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetRegionsDistributionResponse.FromString,
                _registered_method=True)
        self.GetRegionsTree = channel.unary_unary(
                '/yandex.cloud.searchapi.v2.WordstatService/GetRegionsTree',
                request_serializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetRegionsTreeRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetRegionsTreeResponse.FromString,
                _registered_method=True)


class WordstatServiceServicer(object):
    """A set of methods for viewing statistics on search queries to Yandex.
    """

    def GetTop(self, request, context):
        """The method returns the last 30 days data about popular queries containing the specified keyword and queries that are similar to the specified one.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDynamics(self, request, context):
        """The method returns the frequency of queries over time for a given keyword.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRegionsDistribution(self, request, context):
        """The method returns the distribution of the number of queries containing the given keyword globally by region for the last 30 days.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRegionsTree(self, request, context):
        """The method method returns a tree of Wordstat-supported regions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WordstatServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetTop': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTop,
                    request_deserializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetTopRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetTopResponse.SerializeToString,
            ),
            'GetDynamics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDynamics,
                    request_deserializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetDynamicsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetDynamicsResponse.SerializeToString,
            ),
            'GetRegionsDistribution': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRegionsDistribution,
                    request_deserializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetRegionsDistributionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetRegionsDistributionResponse.SerializeToString,
            ),
            'GetRegionsTree': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRegionsTree,
                    request_deserializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetRegionsTreeRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetRegionsTreeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.searchapi.v2.WordstatService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.searchapi.v2.WordstatService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class WordstatService(object):
    """A set of methods for viewing statistics on search queries to Yandex.
    """

    @staticmethod
    def GetTop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.searchapi.v2.WordstatService/GetTop',
            yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetTopRequest.SerializeToString,
            yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetTopResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDynamics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.searchapi.v2.WordstatService/GetDynamics',
            yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetDynamicsRequest.SerializeToString,
            yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetDynamicsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRegionsDistribution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.searchapi.v2.WordstatService/GetRegionsDistribution',
            yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetRegionsDistributionRequest.SerializeToString,
            yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetRegionsDistributionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRegionsTree(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.searchapi.v2.WordstatService/GetRegionsTree',
            yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetRegionsTreeRequest.SerializeToString,
            yandex_dot_cloud_dot_searchapi_dot_v2_dot_wordstat__service__pb2.GetRegionsTreeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LicenseServerMetadata(google.protobuf.message.Message):
    """License server metadata"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    LABELS_FIELD_NUMBER: builtins.int
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the license server"""

    def __init__(
        self,
        *,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["labels", b"labels"]) -> None: ...

global___LicenseServerMetadata = LicenseServerMetadata

@typing.final
class RegisterRequest(google.protobuf.message.Message):
    """Request to register a license server"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """Organization ID"""
    billing_account_id: builtins.str
    """Billing account ID"""
    @property
    def metadata(self) -> global___LicenseServerMetadata:
        """Optional metadata for the license server"""

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        billing_account_id: builtins.str = ...,
        metadata: global___LicenseServerMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "metadata", b"metadata", "organization_id", b"organization_id"]) -> None: ...

global___RegisterRequest = RegisterRequest

@typing.final
class LicenseServer(google.protobuf.message.Message):
    """License server entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    LS_CA_CERTIFICATE_FIELD_NUMBER: builtins.int
    LS_PRIVATE_KEY_FIELD_NUMBER: builtins.int
    VALID_UNTIL_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """Unique server ID"""
    ls_ca_certificate: builtins.str
    """License server CA certificate"""
    ls_private_key: builtins.str
    """Private key for the license server"""
    @property
    def valid_until(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the credentials expire"""

    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
        ls_ca_certificate: builtins.str = ...,
        ls_private_key: builtins.str = ...,
        valid_until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["valid_until", b"valid_until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ls_ca_certificate", b"ls_ca_certificate", "ls_private_key", b"ls_private_key", "server_id", b"server_id", "valid_until", b"valid_until"]) -> None: ...

global___LicenseServer = LicenseServer

@typing.final
class RegisterLicenseServerMetadata(google.protobuf.message.Message):
    """Metadata for register license server operation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """Organization ID"""
    billing_account_id: builtins.str
    """Billing account ID"""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        billing_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "organization_id", b"organization_id"]) -> None: ...

global___RegisterLicenseServerMetadata = RegisterLicenseServerMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/usage_records/v1/consumption_core.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/usage_records/v1/consumption_core.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.billing.usage_records.v1 import billing_types_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_billing__types__pb2
from yandex.cloud.billing.usage_records.v1 import common_types_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_common__types__pb2
from yandex.cloud.billing.usage_records.v1 import credit_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_credit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/billing/usage_records/v1/consumption_core.proto\x12%yandex.cloud.billing.usage_records.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x39yandex/cloud/billing/usage_records/v1/billing_types.proto\x1a\x38yandex/cloud/billing/usage_records/v1/common_types.proto\x1a\x32yandex/cloud/billing/usage_records/v1/credit.proto\"\xa0\x03\n#BillingAccountUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12N\n\x0f\x62illing_account\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.billing.usage_records.v1.BillingAccount\x12P\n\x08periodic\x18\x05 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\x84\x03\n\x1a\x43loudUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12;\n\x05\x63loud\x18\x04 \x01(\x0b\x32,.yandex.cloud.billing.usage_records.v1.Cloud\x12P\n\x08periodic\x18\x05 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\x87\x03\n\x1b\x46olderUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12=\n\x06\x66older\x18\x04 \x01(\x0b\x32-.yandex.cloud.billing.usage_records.v1.Folder\x12P\n\x08periodic\x18\x05 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\x8a\x03\n\x1cServiceUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12?\n\x07service\x18\x04 \x01(\x0b\x32..yandex.cloud.billing.usage_records.v1.Service\x12P\n\x08periodic\x18\x05 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\xce\x03\n\x18SKUUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12N\n\x10pricing_quantity\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12\x37\n\x03sku\x18\x05 \x01(\x0b\x32*.yandex.cloud.billing.usage_records.v1.SKU\x12P\n\x08periodic\x18\x06 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\x8d\x03\n\x1dResourceUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12\x41\n\x08resource\x18\x04 \x01(\x0b\x32/.yandex.cloud.billing.usage_records.v1.Resource\x12P\n\x08periodic\x18\x05 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\x84\x03\n\x1aLabelUsageReportEntityData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12;\n\x05label\x18\x04 \x01(\x0b\x32,.yandex.cloud.billing.usage_records.v1.Label\x12P\n\x08periodic\x18\x05 \x03(\x0b\x32>.yandex.cloud.billing.usage_records.v1.UsageReportPeriodicData\"\xa1\x02\n\x17UsageReportPeriodicData\x12\x42\n\x04\x63ost\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x83\x01\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecordsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.usage_records.v1.consumption_core_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecords'
  _globals['_BILLINGACCOUNTUSAGEREPORTENTITYDATA']._serialized_start=306
  _globals['_BILLINGACCOUNTUSAGEREPORTENTITYDATA']._serialized_end=722
  _globals['_CLOUDUSAGEREPORTENTITYDATA']._serialized_start=725
  _globals['_CLOUDUSAGEREPORTENTITYDATA']._serialized_end=1113
  _globals['_FOLDERUSAGEREPORTENTITYDATA']._serialized_start=1116
  _globals['_FOLDERUSAGEREPORTENTITYDATA']._serialized_end=1507
  _globals['_SERVICEUSAGEREPORTENTITYDATA']._serialized_start=1510
  _globals['_SERVICEUSAGEREPORTENTITYDATA']._serialized_end=1904
  _globals['_SKUUSAGEREPORTENTITYDATA']._serialized_start=1907
  _globals['_SKUUSAGEREPORTENTITYDATA']._serialized_end=2369
  _globals['_RESOURCEUSAGEREPORTENTITYDATA']._serialized_start=2372
  _globals['_RESOURCEUSAGEREPORTENTITYDATA']._serialized_end=2769
  _globals['_LABELUSAGEREPORTENTITYDATA']._serialized_start=2772
  _globals['_LABELUSAGEREPORTENTITYDATA']._serialized_end=3160
  _globals['_USAGEREPORTPERIODICDATA']._serialized_start=3163
  _globals['_USAGEREPORTPERIODICDATA']._serialized_end=3452
# @@protoc_insertion_point(module_scope)
